package com.ruoyi.ss.suit.service.impl;

import com.ruoyi.common.core.domain.BaseValidator;
import com.ruoyi.common.core.domain.ValidateResult;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.ss.device.service.DeviceValidator;
import com.ruoyi.ss.suit.domain.SuitBO;
import com.ruoyi.ss.suit.domain.SuitQuery;
import com.ruoyi.ss.suit.service.SuitService;
import com.ruoyi.ss.suit.service.SuitValidator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * 2024/4/26
 *
 * @author wjh
 */
@Service
public class SuitValidatorImpl extends BaseValidator implements SuitValidator {

    @Autowired
    private DeviceValidator deviceValidator;

    @Autowired
    private SuitService suitService;

    @Override
    public ValidateResult preLogicDel(List<Long> suitIds) {
        if (CollectionUtils.isEmptyElement(suitIds)) {
            return error("数据不允许为空");
        }
        return success();
    }

    /**
     * APP删除前校验
     *
     * @param ids
     */
    @Override
    public ValidateResult preLogicDelByApp(List<Long> ids) {
        ValidateResult result = this.preLogicDel(ids);
        if (result.isError()) {
            return result;
        }

        if (!this.isBelong(ids, SecurityUtils.getUserId())) {
            return error("您没有权限删除这些套餐");
        }

        return success();
    }

    /**
     * APP创建前校验
     *
     * @param suit
     * @return
     */
    @Override
    public ValidateResult preCreateByApp(SuitBO suit) {
        if (suit == null) {
            return error("数据不允许为空");
        }

        // 设备校验
        if (CollectionUtils.isNotEmptyElement(suit.getDeviceIds()) && !deviceValidator.isBelong(suit.getDeviceIds(), SecurityUtils.getUserId())) {
            return error("有设备不属于该用户");
        }

        return success();
    }

    /**
     * APP更新前校验
     *
     * @param suit
     * @return
     */
    @Override
    public ValidateResult preUpdateByApp(SuitBO suit) {
        if (suit == null) {
            return error("数据不允许为空");
        }
        Long userId = SecurityUtils.getUserId();

        // 判断套餐是否属于用户
        if (!this.isBelong(Collections.singletonList(suit.getSuitId()), userId)) {
            return error("您无权修改该套餐");
        }

        // 设备校验
        if (CollectionUtils.isNotEmptyElement(suit.getDeviceIds()) && !deviceValidator.isBelong(suit.getDeviceIds(), SecurityUtils.getUserId())) {
            return error("有设备不属于该用户");
        }

        return success();
    }

    /**
     * 判断这些套餐是否是指定用户的
     */
    @Override
    public boolean isBelong(Collection<Long> ids, Long userId) {
        if (CollectionUtils.isEmptyElement(ids) || userId == null) {
            return false;
        }
        SuitQuery query = new SuitQuery();
        query.setSuitIds(new ArrayList<>(ids));
        query.setUserId(userId);
        return suitService.selectCount(query) == ids.size();
    }
}
